use stm32f0xx_hal::pac::{interrupt, Interrupt, EXTI, RCC, SYSCFG};

pub struct Touch {
    exti: EXTI,
    syscfg: SYSCFG,
}

impl Touch {
    pub fn new(syscfg: SYSCFG, exti: EXTI, rcc: &mut RCC) -> Self {
        cortex_m::interrupt::free(|_| rcc.apb2enr.modify(|_, w| w.syscfgen().set_bit()));

        Self { exti, syscfg }
    }

    pub fn setup(&self) {
        cortex_m::interrupt::free(|_| {
            self.syscfg.exticr1.modify(|_, w| {
                w.exti0().pb0();
                w.exti1().pb1();
                w.exti2().pb2();
                w
            });
            self.syscfg.exticr3.modify(|_, w| {
                w.exti10().pb10();
                w.exti11().pb11();
                w
            });
            self.syscfg.exticr4.modify(|_, w| {
                w.exti13().pc13();
                w.exti14().pc14();
                w.exti15().pc15();
                w
            });

            self.exti.imr.modify(|_, w| {
                w.mr0().unmasked();
                w.mr1().unmasked();
                w.mr2().unmasked();
                w.mr10().unmasked();
                w.mr11().unmasked();
                w.mr13().unmasked();
                w.mr14().unmasked();
                w.mr15().unmasked();
                w
            });

            self.exti.rtsr.modify(|_, w| {
                w.tr0().enabled();
                w.tr1().enabled();
                w.tr2().enabled();
                w.tr10().enabled();
                w.tr11().enabled();
                w.tr13().enabled();
                w.tr14().enabled();
                w.tr15().enabled();
                w
            });

            unsafe {
                cortex_m::peripheral::NVIC::unmask(Interrupt::EXTI0_1);
                cortex_m::peripheral::NVIC::unmask(Interrupt::EXTI2_3);
                cortex_m::peripheral::NVIC::unmask(Interrupt::EXTI4_15);
            }

            cortex_m::peripheral::NVIC::unpend(Interrupt::EXTI0_1);
            cortex_m::peripheral::NVIC::unpend(Interrupt::EXTI2_3);
            cortex_m::peripheral::NVIC::unpend(Interrupt::EXTI4_15);
        });
    }
}

#[interrupt]
fn EXTI0_1() {}

#[interrupt]
fn EXTI2_3() {}

#[interrupt]
fn EXTI4_15() {}
